@@ -44,5 +44,5 @@ main.add_command(git_river.commands.forge.main)
 main.add_command(git_river.commands.repo.fetch_remotes)
 main.add_command(git_river.commands.repo.merge_feature_branches)
 main.add_command(git_river.commands.repo.tidy_branches)
-main.add_command(git_river.commands.repo.restart)
+main.add_command(git_river.commands.repo.rebase)
 main.add_command(git_river.commands.repo.end)
