@@ -35,6 +35,10 @@ p = inflect.engine()
 logger = structlog.get_logger(logger_name=__name__)
 
 
+class Missing(ValueError):
+    pass
+
+
 @dataclasses.dataclass(frozen=True)
 class GitConfigKey:
     section: str
@@ -230,16 +234,21 @@ class LocalRepository(Repository):
         """Remove branches that have been merged into the repo's default branch."""
         log = self.bind(logger).bind(target=target, dry_run=dry_run)
         merged_branches = self.merged(target)
+        active_branch = self.repo.active_branch.name
         for merged_branch in merged_branches:
+            if active_branch == merged_branch:
+                log.debug("Skipping current branch", head=merged_branch)
+                continue
+
             if merged_branch.startswith("release/"):
+                log.debug("Skipping release/* branch", head=merged_branch)
                 continue
 
             if dry_run:
                 log.info("Would delete branch", head=merged_branch)
-                continue
-
-            log.info("Deleting branch", head=merged_branch)
-            self.repo.delete_head(merged_branch)
+            else:
+                log.info("Deleting branch", head=merged_branch)
+                self.repo.delete_head(merged_branch)
 
     def merged(self, target: str) -> typing.Set[str]:
         """Return a list of branches merged into a target branch."""
@@ -320,7 +329,7 @@ class LocalRepository(Repository):
             except IndexError:
                 pass
 
-        raise ValueError(f"No heads found for {names!r}")
+        raise Missing(f"No heads found for {names!r}")
 
     def discover_mainline_branch(self, override: typing.Optional[str] = None) -> str:
         if override is not None:
@@ -338,7 +347,7 @@ class LocalRepository(Repository):
             except ValueError:
                 pass
 
-        raise ValueError(f"No remotes found for {names!r}")
+        raise Missing(f"No remotes found for {names!r}")
 
     def discover_upstream_remote(self, override: typing.Optional[str] = None) -> str:
         if override is not None:
@@ -352,13 +361,29 @@ class LocalRepository(Repository):
 
         return self.discover_remote("downstream")
 
+    def discover_optional_downstream_remote(
+        self,
+        override: typing.Optional[str] = None,
+    ) -> typing.Optional[str]:
+        """
+        If we can't find a downstream remote, return None instead of raising an error.
+
+        An error is still raised if a remote was explicitly specified.
+        """
+        if override is not None:
+            return self._remote(override)
+
+        try:
+            return self.discover_remote("downstream")
+        except Missing:
+            return None
+
     def _head(self, name: str) -> str:
         """Check a head exists."""
         try:
             head = self.repo.heads[name]
         except ValueError as error:
-            logger.debug("No head found", name=name)
-            raise error
+            raise Missing(f"No head found named {name!r}") from error
         return head.name
 
     def _remote(self, name: str) -> str:
@@ -366,6 +391,5 @@ class LocalRepository(Repository):
         try:
             remote = self.repo.remote(name)
         except ValueError as error:
-            logger.debug("No remote found", name=name)
-            raise error
+            raise Missing(f"No remote found named {name!r}") from error
         return remote.name
